==> apache-storm-2.1.1-src.tar.gz: apache-storm-2.1.1/examples/storm-perf/src/main/java/org/apache/storm/perf/queuetest/AckingProducer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License
 */

package org.apache.storm.perf.queuetest;

import org.apache.storm.utils.JCQueue;

/**
 * Writes to two queues.
 */
class AckingProducer extends MyThread {
    private final JCQueue ackerInQ;
    private final JCQueue spoutInQ;

    public AckingProducer(JCQueue ackerInQ, JCQueue spoutInQ) {
        super("AckingProducer");
        this.ackerInQ = ackerInQ;
        this.spoutInQ = spoutInQ;
    }

    @Override
    public void run() {
        try {
            Handler handler = new Handler();
            long start = System.currentTimeMillis();
            while (!Thread.interrupted()) {
                int x = spoutInQ.consume(handler);
                ackerInQ.publish(count);
            }
            runTime = System.currentTimeMillis() - start;
        } catch (InterruptedException e) {
            return;
        }
    }

    private class Handler implements JCQueue.Consumer {
        @Override
        public void accept(Object event) {
            // no-op
        }

        @Override
        public void flush() {
            // no-op
        }
    }
}

==> apache-storm-2.6.2-src.tar.gz: apache-storm-2.6.2/examples/storm-perf/src/main/java/org/apache/storm/perf/queuetest/AckingProducer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License
 */

package org.apache.storm.perf.queuetest;

import org.apache.storm.utils.JCQueue;

/**
 * Writes to two queues.
 */
class AckingProducer extends MyThread {
    private final JCQueue ackerInQ;
    private final JCQueue spoutInQ;

    AckingProducer(JCQueue ackerInQ, JCQueue spoutInQ) {
        super("AckingProducer");
        this.ackerInQ = ackerInQ;
        this.spoutInQ = spoutInQ;
    }

    @Override
    public void run() {
        try {
            Handler handler = new Handler();
            long start = System.currentTimeMillis();
            while (!Thread.interrupted()) {
                int x = spoutInQ.consume(handler);
                ackerInQ.publish(count);
            }
            runTime = System.currentTimeMillis() - start;
        } catch (InterruptedException e) {
            return;
        }
    }

    private class Handler implements JCQueue.Consumer {
        @Override
        public void accept(Object event) {
            // no-op
        }

        @Override
        public void flush() {
            // no-op
        }
    }
}
